@@ -525,7 +525,7 @@ append_clock_menu (FoobarWidget *foo, GtkWidget *menu_bar)
 	item = gtk_menu_item_new ();
 
 	foo->clock_label = gtk_label_new ("");
-	foo->clock_timeout = gtk_timeout_add (1000, timeout_cb, foo);
+	foo->clock_timeout = g_timeout_add (1000, timeout_cb, foo);
 
 	foo->clock_ebox = item;
 	gtk_container_add (GTK_CONTAINER (item), foo->clock_label);
@@ -549,6 +549,20 @@ foobar_widget_global_set_clock_format (const char *format)
 	}
 }
 
+/*
+ * FIXME: we should be only saving Foobar specific prefs
+ */
+static void
+foobar_save_to_gconf (FoobarWidget *foo)
+{
+	PanelData *pd;
+
+	pd = g_object_get_data (G_OBJECT (foo), "PanelData");
+
+	if (pd)
+		panel_save_to_gconf (pd);
+}
+
 void
 foobar_widget_set_clock_format (FoobarWidget *foo, const char *clock_format)
 {
@@ -608,6 +622,8 @@ foobar_widget_set_clock_format (FoobarWidget *foo, const char *clock_format)
 	}
 
 	update_clock (foo);
+
+	foobar_save_to_gconf (foo);
 }
 
 void
@@ -1162,7 +1178,7 @@ foobar_widget_destroy (GtkObject *o)
 	foobars = g_list_remove (foobars, foo);
 
 	if (foo->clock_timeout != 0)
-		gtk_timeout_remove (foo->clock_timeout);
+		g_source_remove (foo->clock_timeout);
 	foo->clock_timeout = 0;
 	
 	foo->clock_label = NULL;
