@@ -40,6 +40,7 @@ struct _FileRec {
 	char *name;
 	char *comment;
 	char *fullname;
+	char *name_collate_key;
 	char *icon;
 	char *tryexec_path;
 	DirRec *parent;
@@ -57,14 +58,15 @@ struct _DirRec {
 	GSList *mfl;  /*records of menus using this record*/
 };
 
-GSList * get_mfiles_from_menudir(const char *menudir);
+GSList * get_mfiles_from_menudir (const char *menudir, gboolean *sorted);
 
 FileRec * fr_read_dir(DirRec *dr, const char *muri, time_t mtime, int sublevels);
 FileRec * fr_replace(FileRec *fr);
 FileRec * fr_check_and_reread(FileRec *fr);
 FileRec * fr_get_dir(const char *mdir);
 void fr_force_reread(void);
-GSList* fr_get_all_dirs (void);
+
+int fr_compare (FileRec *fra, FileRec *frb);
 
 void free_mfile (MFile *mfile);
 void free_mfile_list (GSList *list);
